<?php
/* 
	Plugin Name: Extra Post Images
	Plugin URI: http://michael-cole-web.co.uk/
	Description: This plugin allows extra images to be attached to any post type.
	Version: 1.0
	Author: Michael Cole
	Author URI: http://michael-cole-web.co.uk/
*/
add_action( 'admin_init', 'init_meta_boxes' );

function init_meta_boxes() {
	$types = _get_post_types();
	foreach($types as $type):
    	add_meta_box('extra_image', 'Extra Images', 'extra_image', $type, 'side', 'default');
	endforeach;
}

add_action('admin_head', 'my_custom_js');

function my_custom_js() {
    $head = '<script type="text/javascript" src="'. plugin_dir_url( __FILE__ ).'script.js"></script>';
    $head .= '<link type="text/css" rel="stylesheet" href="'. plugin_dir_url( __FILE__ ).'epi.css"/>';
    echo $head;
}

function _get_post_types(){
	$unused = array('attachment','revision','nav_menu_item');
	$types = get_post_types('', 'names' ); 
	foreach($unused as $key):
		unset($types[$key]);
	endforeach;
	return $types;
}

function extra_image($post) {
    $extra_image = get_post_meta($post->ID, 'extra-image-input', true);
    $extra_images = explode('|', $extra_image);
    $html = '<div id="extra-images">';
        $html .= '<button id="add_img_row" class="button" style="float:right;">Add Image</button>';
        $html .= '<input type="hidden" name="extra-image-input" id="extra-image-input"/>';
        if(count($extra_images)):
            foreach ($extra_images as $key => $img):
                $html .= '
                <div class="extra-image" data-image-id="'.$img.'">
                    <p class="hide-if-no-js">
                        '.wp_get_attachment_image($img, 'medium').'
                        <button class="add-extra-thumbnail button-primary">Add extra image</button>
                    </p>
                    <p class="hide-if-no-js">
                        <a href="#" class="remove-extra-thumbnail">Remove extra image</a>
                    </p>
                </div>';
            endforeach;
        else:
            $html .= '
            <div class="extra-image" data-image-id="">
                <p class="hide-if-no-js">
                    <button class="add-extra-thumbnail button-primary">Add extra image</button>
                </p>
                <p class="hide-if-no-js">
                    <a href="#" class="remove-extra-thumbnail">Remove extra image</a>
                </p>
            </div>';
        endif;

    $html .= '</div>';
    echo $html;
}

add_action('save_post', 'save_details');

function save_details(){
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
		return $post_id;
	global $post;
	update_post_meta($post->ID, 'extra-image-input', $_POST["extra-image-input"]);
}

add_shortcode('extra-images', 'extra_images_shortcode');
function extra_images_shortcode($atts){
	ob_start();
	global $post;
	$imgs = explode('|', get_post_meta($post->ID, 'extra-image-input', true));
	extract(shortcode_atts(array(
		'type' => 'list', // list, html5 (figure tag)
		'size' => 'medium', // thumbnail, medium, large or full
		'id' => 'extra-images'
	), $atts));
	if($type == 'list'):
		if(count($imgs) > 0):
			$html = '<ul id="'.$id.'">';
			foreach ($imgs as $img):
				$html .= '<li><a href="'.wp_get_attachment_url($img, 'full').'">'.wp_get_attachment_image($img, $size).'</a></li>';
			endforeach;
			$html .= '</ul>';
			echo $html;
		endif;
	elseif($type == 'html5'):
		if(count($imgs) > 0):
			$html = '<figure id="'.$id.'">';
			foreach ($imgs as $img):
				$html .= '<a href="'.wp_get_attachment_url($img, 'full').'">'.wp_get_attachment_image($img, $size).'</a>';
			endforeach;
			$html .= '</figure>';
			echo $html;
		endif;
	endif;
	return ob_get_clean();
}


